@@ -59,13 +59,7 @@ from autolens.pipeline.phase.imaging.phase import PhaseImaging
 from autolens.pipeline.phase.interferometer.phase import PhaseInterferometer
 from autolens.pipeline.phase.phase_galaxy import PhaseGalaxy
 from autolens.pipeline.pipeline import PipelineDataset, PipelinePositions
-from autolens.pipeline.pipeline_settings import (
-    PipelineGeneralSettings,
-    PipelineSourceSettings,
-    PipelineLightSettings,
-    PipelineMassSettings,
-)
-from autolens.pipeline import pipeline_settings
+from autolens.pipeline import setup
 from autolens import plot
 
-__version__ = '0.35.2'
+__version__ = '0.40.0'
