@@ -129,7 +129,9 @@ class PhaseDatasetVisualizer(AbstractVisualizer):
         self.plot_fit_all_at_end_png = plot_setting("fit", "all_at_end_png")
         self.plot_fit_all_at_end_fits = plot_setting("fit", "all_at_end_fits")
         self.plot_subplot_fit = plot_setting("fit", "subplot_fit")
-        self.plot_subplot_of_plane_fits = plot_setting("fit", "subplots_of_plane_fits")
+        self.plot_subplots_of_all_planes_fits = plot_setting(
+            "fit", "subplots_of_plane_fits"
+        )
 
         self.plot_fit_data = plot_setting("fit", "data")
         self.plot_fit_noise_map = plot_setting("fit", "noise_map")
@@ -234,24 +236,25 @@ class PhaseDatasetVisualizer(AbstractVisualizer):
 
             if self.plot_ray_tracing_all_at_end_fits:
 
-                fits_plotter = plotter.plotter_with_new_output(
-                    path=plotter.output.path + "/fits/", format="fits"
-                )
+                self.visualize_ray_tracing_in_fits(tracer=tracer)
 
-                ray_tracing_plots.individual(
-                    tracer=tracer,
-                    grid=self.masked_dataset.grid,
-                    positions=self.include.positions_from_masked_dataset(
-                        masked_dataset=self.masked_dataset
-                    ),
-                    plot_profile_image=True,
-                    plot_source_plane=True,
-                    plot_convergence=True,
-                    plot_potential=True,
-                    plot_deflections=True,
-                    include=self.include,
-                    plotter=fits_plotter,
-                )
+    def visualize_ray_tracing_in_fits(self, tracer):
+
+        fits_plotter = self.plotter.plotter_with_new_output(
+            path=self.plotter.output.path + "/ray_tracing/fits/", format="fits"
+        )
+
+        ray_tracing_plots.individual(
+            tracer=tracer,
+            grid=self.masked_dataset.grid,
+            plot_profile_image=True,
+            plot_source_plane=True,
+            plot_convergence=True,
+            plot_potential=True,
+            plot_deflections=True,
+            include=self.include,
+            plotter=fits_plotter,
+        )
 
 
 class PhaseImagingVisualizer(PhaseDatasetVisualizer):
@@ -269,7 +272,9 @@ class PhaseImagingVisualizer(PhaseDatasetVisualizer):
 
         if results is not None and results.last is not None:
 
-            self.visualize_hyper_images(last_results=results.last)
+            if hasattr(results.last, "hyper_model_image"):
+
+                self.visualize_hyper_images(last_results=results.last)
 
     @property
     def masked_imaging(self):
@@ -323,8 +328,8 @@ class PhaseImagingVisualizer(PhaseDatasetVisualizer):
                 fit=fit, include=self.include, sub_plotter=self.sub_plotter
             )
 
-        if self.plot_subplot_of_plane_fits:
-            fit_imaging_plots.subplot_of_planes(
+        if self.plot_subplots_of_all_planes_fits:
+            fit_imaging_plots.subplots_of_all_planes(
                 fit=fit, include=self.include, sub_plotter=self.sub_plotter
             )
 
@@ -455,52 +460,45 @@ class PhaseImagingVisualizer(PhaseDatasetVisualizer):
                     )
 
             if self.plot_fit_all_at_end_fits:
-                fits_plotter = plotter.plotter_with_new_output(
-                    path=plotter.output.path + "/fits/", format="fits"
-                )
 
-                fit_imaging_plots.individuals(
-                    fit=fit,
-                    plot_image=True,
-                    plot_noise_map=True,
-                    plot_signal_to_noise_map=True,
-                    plot_model_image=True,
-                    plot_residual_map=True,
-                    plot_normalized_residual_map=True,
-                    plot_chi_squared_map=True,
-                    plot_subtracted_images_of_planes=True,
-                    plot_model_images_of_planes=True,
-                    plot_plane_images_of_planes=True,
-                    include=self.include,
-                    plotter=fits_plotter,
-                )
+                self.visualize_fit_in_fits(fit=fit)
 
-                if fit.inversion is not None:
-                    inversion_plots.individuals(
-                        inversion=fit.inversion,
-                        image_positions=self.include.positions_from_fit(fit=fit),
-                        source_positions=self.include.positions_of_plane_from_fit_and_plane_index(
-                            fit=fit, plane_index=-1
-                        ),
-                        grid=self.include.inversion_image_pixelization_grid_from_fit(
-                            fit=fit
-                        ),
-                        light_profile_centres=self.include.light_profile_centres_of_galaxies_from_obj(
-                            obj=fit.tracer.image_plane
-                        ),
-                        mass_profile_centres=self.include.mass_profile_centres_of_galaxies_from_obj(
-                            obj=fit.tracer.image_plane
-                        ),
-                        critical_curves=self.include.critical_curves_from_obj(
-                            obj=fit.tracer
-                        ),
-                        caustics=self.include.caustics_from_obj(obj=fit.tracer),
-                        plot_reconstructed_image=True,
-                        plot_interpolated_reconstruction=True,
-                        plot_interpolated_errors=True,
-                        include=self.include,
-                        plotter=plotter,
-                    )
+    def visualize_fit_in_fits(self, fit):
+
+        fits_plotter = self.plotter.plotter_with_new_output(
+            path=self.plotter.output.path + "fit_imaging/fits/", format="fits"
+        )
+
+        fit_imaging_plots.individuals(
+            fit=fit,
+            plot_image=True,
+            plot_noise_map=True,
+            plot_signal_to_noise_map=True,
+            plot_model_image=True,
+            plot_residual_map=True,
+            plot_normalized_residual_map=True,
+            plot_chi_squared_map=True,
+            plot_subtracted_images_of_planes=True,
+            plot_model_images_of_planes=True,
+            plot_plane_images_of_planes=True,
+            include=self.include,
+            plotter=fits_plotter,
+        )
+
+        if fit.inversion is not None:
+
+            fits_plotter = self.plotter.plotter_with_new_output(
+                path=self.plotter.output.path + "inversion/fits/", format="fits"
+            )
+
+            inversion_plots.individuals(
+                inversion=fit.inversion,
+                plot_reconstructed_image=True,
+                plot_interpolated_reconstruction=True,
+                plot_interpolated_errors=True,
+                include=self.include,
+                plotter=fits_plotter,
+            )
 
     def visualize_hyper_images(self, last_results):
 
