@@ -4,7 +4,7 @@ import autofit as af
 import autolens as al
 
 
-class GalaxiesMockAnalysis(object):
+class GalaxiesMockAnalysis:
     def __init__(self, number_galaxies, value):
         self.number_galaxies = number_galaxies
         self.value = value
@@ -17,7 +17,7 @@ class GalaxiesMockAnalysis(object):
         return 1
 
 
-class MockResults(object):
+class MockResults:
     def __init__(
         self,
         model_image=None,
@@ -101,9 +101,9 @@ class MockResults(object):
 
 
 class MockResult:
-    def __init__(self, instance, figure_of_merit, model=None):
+    def __init__(self, instance, likelihood, model=None):
         self.instance = instance
-        self.figure_of_merit = figure_of_merit
+        self.likelihood = likelihood
         self.model = model
         self.previous_model = model
         self.gaussian_tuples = None
@@ -111,7 +111,7 @@ class MockResult:
         self.positions = None
 
 
-class MockHyperCombinedPhase(object):
+class MockHyperCombinedPhase:
     def __init__(self):
         pass
 
@@ -122,13 +122,13 @@ class MockHyperCombinedPhase(object):
 
 class MockNLO(af.NonLinearOptimizer):
     def fit(self, analysis, model):
-        class Fitness(object):
-            def __init__(self, instance_from_physical_vector):
+        class Fitness:
+            def __init__(self, instance_from_vector):
                 self.result = None
-                self.instance_from_physical_vector = instance_from_physical_vector
+                self.instance_from_vector = instance_from_vector
 
             def __call__(self, vector):
-                instance = self.instance_from_physical_vector(vector)
+                instance = self.instance_from_vector(vector)
 
                 likelihood = analysis.fit(instance)
                 self.result = MockResult(instance, likelihood)
@@ -136,7 +136,7 @@ class MockNLO(af.NonLinearOptimizer):
                 # Return Chi squared
                 return -2 * likelihood
 
-        fitness_function = Fitness(model.instance_from_physical_vector)
+        fitness_function = Fitness(model.instance_from_vector)
         fitness_function(model.prior_count * [0.8])
 
         return fitness_function.result
